==> fuel-ui-0.4.1-3.tgz: package/esm/directives/directives.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule } from "@angular/core";
import { CommonModule } from "@angular/common";
import { FuiAnimationModule } from './animation/animation';
import { FuiTooltipModule } from "./tooltip/tooltip";
import { FuiCodeHighlighterModule } from "./codeHighlighter/codeHighlighter";
export * from './animation/animation';
export * from "./tooltip/tooltip";
export * from "./codeHighlighter/codeHighlighter";
const directiveModules = [
    FuiAnimationModule,
    FuiTooltipModule,
    FuiCodeHighlighterModule
];
export let FuiDirectivesModule = class FuiDirectivesModule {
};
FuiDirectivesModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            ...directiveModules
        ],
        exports: directiveModules
    }), 
    __metadata('design:paramtypes', [])
], FuiDirectivesModule);

==> fuel-ui-0.4.1-5.tgz: package/esm/directives/directives.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule } from "@angular/core";
import { CommonModule } from "@angular/common";
import { FuiAnimationModule } from './Animation/Animation';
import { FuiTooltipModule } from "./Tooltip/Tooltip";
import { FuiCodeHighlighterModule } from "./CodeHighlighter/CodeHighlighter";
export * from './Animation/Animation';
export * from "./Tooltip/Tooltip";
export * from "./CodeHighlighter/CodeHighlighter";
const directiveModules = [
    FuiAnimationModule,
    FuiTooltipModule,
    FuiCodeHighlighterModule
];
export let FuiDirectivesModule = class FuiDirectivesModule {
};
FuiDirectivesModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            ...directiveModules
        ],
        exports: directiveModules
    }), 
    __metadata('design:paramtypes', [])
], FuiDirectivesModule);
